package com.mindoo.ftp.internal;

import org.eclipse.osgi.framework.console.CommandInterpreter;
import org.eclipse.osgi.framework.console.CommandProvider;

import com.mindoo.ftp.controller.FTPController;

/**
 * OSGi commands to control the FTP server state
 * 
 * @author Karsten Lehmann
 */
public class FTPCommandProvider implements CommandProvider {

	public void _mftp(CommandInterpreter ci) {
		String command=ci.nextArgument();
		if ("start".equals(command)) {
			try {
				if (FTPController.isRunning()) {
					ci.println("Server is already running.");
				}
				else {
					ci.println("Starting server");
					FTPController.startServer();
					ci.println("Server started.");
				}
			}
			catch (Exception e) {
				ci.printStackTrace(e);
			}
		}
		else if ("stop".equals(command)) {
			try {
				if (FTPController.isRunning()) {
					ci.println("Stopping server");
					FTPController.stopServer();
					ci.println("Server stopped.");
				}
				else {
					ci.println("Server is not running.");
				}
			}
			catch (Exception e) {
				ci.printStackTrace(e);
			}
		}
		else if ("restart".equals(command)) {
			try {
				ci.println("Restarting server");
				FTPController.restartServer();
				ci.println("Server restarted.");
			}
			catch (Exception e) {
				ci.printStackTrace(e);
			}
		}
		else
			ci.println(getHelp());
	}

	@Override
	public String getHelp() {
		return "---Mindoo FTP Server Commands---\n"+
		"\tmftp start - starts the server (server is automatically started on HTTP startup)\n"+
		"\tmftp stop - stops the server (server is automatically stopped on HTTP shutdown)\n"+
		"\tmftp restart - restarts the server and reloads the configuration\n";
	}

}
